[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)
    * [Logos](https://git-scm.com/community/logos)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
#  Community
##  [](https://git-scm.com/community#git-mailing-list) Mailing List
General questions or comments for the Git community can be sent to the mailing list by using the email address git@vger.kernel.org.
**If you wish to report any possible bug for Git, please use this mailing list as well.**
You do not need to subscribe: you will be Cc'd in replies. Please keep the Cc list intact when replying (use "Reply to all"). Greylisting may delay your first post for a few hours. Note also that the list only accepts [plain-text email](https://useplaintext.email/); please disable HTML in your outgoing messages.
By subscribing (click here), you can make sure you're not missing follow-up discussions and you can also learn about other development in the community. The list [archive](https://lore.kernel.org/git/) can be found on lore.kernel.org.
Windows-specific questions can also be asked at [Git for Windows' discussions](https://github.com/git-for-windows/git/discussions/) (if in doubt whether your question is Windows-specific, or if you prefer mailing lists or want to avoid GitHub, just use the general Git mailing list). Please submit Windows-specific bugs to [Git for Windows' bug tracker](https://github.com/git-for-windows/git/issues).
If you're a downstream packager of Git, consider joining the [Git packagers mailing list](https://groups.google.com/forum/?fromgroups#!forum/git-packagers) for low-volume announcements from the developers, as well as other discussion related to packaging & porting Git.
##  [](https://git-scm.com/community#reporting-bugs) Bug Reporting
Bugs in git can be reported directly to the mailing list (see above for details). Note that you do not need to subscribe to the list to send to it. You can help us out by attempting to reproduce the bug in the latest released version of git, or if you're willing to build git from source, the [next branch](https://github.com/git/git/tree/next). Sometimes an attempted fix may be pending in this branch, in which case your feedback as to whether the fix worked for you will be appreciated.
If you are using git 2.27.0 or later, you can run [git bugreport](https://git-scm.com/docs/git-bugreport) in the repository where you observed the bug, which generates a template to guide you through writing a useful bug report and gathers some diagnostic information about your environment.
Bugs related to this website can be reported at its [issue tracker](https://github.com/git/git-scm.com/issues). Bugs related to the content of the "Pro Git" book can be reported at its [issue tracker](https://github.com/progit/progit2).
If you are new to submitting bugs, you might find [this guide](http://www.chiark.greenend.org.uk/~sgtatham/bugs.html) helpful for producing useful bug reports.
##  [](https://git-scm.com/community#git-security) Reporting Security Issues
Issues which are security relevant should be disclosed privately to the Git Security mailing list.
##  [](https://git-scm.com/community#irc) IRC Channel
If the manpages and this book aren’t enough and you need in-person help, you can try the #git channel on the [Libera Chat](https://libera.chat/guides/connect) IRC server (**irc.libera.chat**). These channels are regularly filled with hundreds of people who are all very knowledgeable about Git and are often willing to help. The #git-devel channel welcomes Git development discussion, and might be able to help you contribute to Git.
If you need specific help about one of the for-profit Git hosting sites, you might try their own IRC channels (such as #github or #gitlab) on the same IRC server.
##  [](https://git-scm.com/community#discord) Discord Server
The [Git Community Discord Server](https://discord.gg/GRFVkzgxRd) also has many knowledgeable and helpful people. Additionally, it provides a space to be able to voice chat about patches, designs, or anything else Git related.
##  [](https://git-scm.com/community#logos) Logos
Various [Git logos](https://git-scm.com/community/logos) in PNG (bitmap) and EPS (vector) formats are available for use in online and print projects.
##  [](https://git-scm.com/community#git-rev-news) Newsletter
There is a monthly community newsletter called ["Git Rev News"](https://git.github.io/rev_news/rev_news/), with [its archive](https://git.github.io/rev_news/archive/) and [its latest edition](https://git.github.io/rev_news/). Information on how to subscribe can be found on the [dedicated webpage](https://git.github.io/rev_news/rev_news/).
##  [](https://git-scm.com/community#contributing) Contributing to Git
The [Documentation directory](https://github.com/git/git/tree/master/Documentation) in the Git source code has several files of interest to developers who are looking to help contribute. After reading the [coding guidelines](https://git-scm.com/docs/CodingGuidelines) and [code of conduct](https://github.com/git/git/blob/master/CODE_OF_CONDUCT.md), you can learn [how to submit patches](https://git-scm.com/docs/SubmittingPatches). If you are just starting out, you can read the [My First Contribution tutorial](https://git-scm.com/docs/MyFirstContribution). For those looking to get more deeply involved, there is a [howto for Git maintainers](https://github.com/git/git/blob/master/Documentation/howto/maintain-git.adoc).
The [Git Developer Pages](https://git.github.io/) have a [Hacking Git page](https://git.github.io/Hacking-Git/) which lists useful development resources. They also have [information](https://git.github.io/General-Application-Information/) for people applying to work on Git as part of programs like [Outreachy](https://www.outreachy.org/) or the [Google Summer of Code](https://summerofcode.withgoogle.com/).
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
